rhmap

package
v0.1.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 11, 2022 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Map

type Map struct {
	// contains filtered or unexported fields
}

Map is a hashset that uses the robinhood algorithm. This implementation is not concurrent safe.

func NewMap

func NewMap(size uintptr) Map

NewMap returns a new robinhood hashmap.

func NewMapPtrPtr

func NewMapPtrPtr(size uintptr) Map

NewMap returns a new robinhood hashmap.

func (*Map) Close

func (ps *Map) Close() error

func (*Map) Delete

func (ps *Map) Delete(key Bytes) (Bytes, bool)

Delete removes a key from the Map.

func (*Map) Get

func (ps *Map) Get(key Bytes) (Bytes, bool)

Get returns whether the key exists in the Add.

func (*Map) Grow

func (ps *Map) Grow() bool

func (*Map) Has

func (ps *Map) Has(key Bytes) bool

Has returns whether the key exists in the Add.

func (*Map) Reset

func (ps *Map) Reset()

Reset clears Map, where already allocated memory will be reused.

func (*Map) Set

func (ps *Map) Set(key Bytes, value Bytes) (Bytes, bool, bool)

type MapInt64

type MapInt64 struct {
	// contains filtered or unexported fields
}

MapInt64 is a hashset that uses the robinhood algorithm. This implementation is not concurrent safe.

func NewMapInt64

func NewMapInt64(size uintptr) MapInt64

NewMapInt64 returns a new robinhood hashmap.

func (*MapInt64) Close

func (ps *MapInt64) Close() error

func (*MapInt64) Delete

func (ps *MapInt64) Delete(key int64) (uintptr, bool)

Delete removes a key from the Map.

func (*MapInt64) Get

func (ps *MapInt64) Get(key int64) (uintptr, bool)

Get returns whether the key exists in the Add.

func (*MapInt64) Grow

func (ps *MapInt64) Grow() bool

func (*MapInt64) Has

func (ps *MapInt64) Has(key int64) bool

Has returns whether the key exists in the Add.

func (*MapInt64) Reset

func (ps *MapInt64) Reset()

Reset clears Map, where already allocated memory will be reused.

func (*MapInt64) Set

func (ps *MapInt64) Set(key int64, value uintptr) (uintptr, bool, bool)

type MapPtrPtr

type MapPtrPtr struct {
	// contains filtered or unexported fields
}

MapPtrPtr is a hashset that uses the robinhood algorithm. This implementation is not concurrent safe.

func (*MapPtrPtr) Close

func (ps *MapPtrPtr) Close() error

func (*MapPtrPtr) Delete

func (ps *MapPtrPtr) Delete(key Bytes) (Bytes, bool)

Delete removes a key from the Map.

func (*MapPtrPtr) Get

func (ps *MapPtrPtr) Get(key Bytes) (Bytes, bool)

Get returns whether the key exists in the Add.

func (*MapPtrPtr) Grow

func (ps *MapPtrPtr) Grow() bool

func (*MapPtrPtr) Has

func (ps *MapPtrPtr) Has(key Bytes) bool

Has returns whether the key exists in the Add.

func (*MapPtrPtr) Reset

func (ps *MapPtrPtr) Reset()

Reset clears Map, where already allocated memory will be reused.

func (*MapPtrPtr) Set

func (ps *MapPtrPtr) Set(key Bytes, value Bytes) (Bytes, bool, bool)

Jump to