Documentation
¶
Index ¶
- type Map
- type MapInt64
- func (ps *MapInt64) Close() error
- func (ps *MapInt64) Delete(key int64) (uintptr, bool)
- func (ps *MapInt64) Get(key int64) (uintptr, bool)
- func (ps *MapInt64) Grow() bool
- func (ps *MapInt64) Has(key int64) bool
- func (ps *MapInt64) Reset()
- func (ps *MapInt64) Set(key int64, value uintptr) (uintptr, bool, bool)
- type MapPtrPtr
- func (ps *MapPtrPtr) Close() error
- func (ps *MapPtrPtr) Delete(key Bytes) (Bytes, bool)
- func (ps *MapPtrPtr) Get(key Bytes) (Bytes, bool)
- func (ps *MapPtrPtr) Grow() bool
- func (ps *MapPtrPtr) Has(key Bytes) bool
- func (ps *MapPtrPtr) Reset()
- func (ps *MapPtrPtr) Set(key Bytes, value Bytes) (Bytes, bool, bool)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Map ¶
type Map struct {
// contains filtered or unexported fields
}
Map is a hashset that uses the robinhood algorithm. This implementation is not concurrent safe.
type MapInt64 ¶
type MapInt64 struct {
// contains filtered or unexported fields
}
MapInt64 is a hashset that uses the robinhood algorithm. This implementation is not concurrent safe.
func NewMapInt64 ¶
NewMapInt64 returns a new robinhood hashmap.
type MapPtrPtr ¶
type MapPtrPtr struct {
// contains filtered or unexported fields
}
MapPtrPtr is a hashset that uses the robinhood algorithm. This implementation is not concurrent safe.
Click to show internal directories.
Click to hide internal directories.